==> pan-0.11.3.tar.bz2: pan-0.11.3/pan/identities/identity-edit-ui.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Author: Charles Kerr <charles@rebelbase.com>
 *
 * Pan - A Newsreader for X
 * Copyright (C) 2001  Pan Development Team <pan@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 */

#include <gtk/gtkwidget.h>
#include <pan/rules/rule.h>

/*
** Ugly as sin. Need to think of something better
**/


GtkWidget*  identity_edit_dialog_new          (const Identity   * id,
                                               gboolean           default_news,
                                               gboolean           default_mail);

Identity*   identity_edit_dialog_get_identity (GtkWidget        * w,
                                               gboolean         * default_news,
                                               gboolean         * default_mail);

enum {
	IDENTITY_EDIT_DIALOG_CLICKED_DONE = 0,
	IDENTITY_EDIT_DIALOG_CLICKED_CANCEL = 1
};

==> pan-0.13.2.tar.bz2: pan-0.13.2/pan/identities/identity-edit-ui.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Pan - A Newsreader for Gtk+
 * Copyright (C) 2002  Charles Kerr <charles@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <gtk/gtkwindow.h>
#include <pan/rules/rule.h>

/*
** Ugly as sin. Need to think of something better
**/


/**
 * GTK_RESPONSE_OK
 * GTK_RESPONSE_CANCEL
 */
GtkWidget*  identity_edit_dialog_new          (GtkWindow        * window,
                                               const Identity   * id,
                                               gboolean           default_news,
                                               gboolean           default_mail);

Identity*   identity_edit_dialog_get_identity (GtkWidget        * w,
                                               gboolean         * default_news,
                                               gboolean         * default_mail);
